========================================
``psyclone.tests.nemo.nemo_config_test``
========================================

.. automodule:: psyclone.tests.nemo.nemo_config_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.nemo.nemo_config_test
